@@ -63,7 +63,8 @@
 #   define DPRINTF(args) 
 #endif
 
-#define PID_PROPERTY_NAME "XALF_LAUNCH_PID"
+#define PID_ENV_NAME "XALF_LAUNCH_PID"
+#define SAVED_PRELOAD_NAME "XALF_SAVED_PRELOAD"
 #define PRELOAD_LIBRARY LIBDIR"/libxalflaunch.so.0"
 #define USAGE "\
 Usage: %s [options] command\n\
@@ -252,20 +253,29 @@ forced_mappingmode(char **argv) {
     int mappingmode_opt = FALSE;
     
 #ifndef MULTI_PRELOAD
-    /* If LD_PRELOAD is alread set and this system does not support 
-       multiple libs in LD_PRELOAD, use use --mappingmode. */
-    if (getenv("LD_PRELOAD") != NULL)
-        {
-            fprintf (stderr, 
-                     "%s: LD_PRELOAD is already set. Using --mappingmode\n", 
-                     programname);
-            mappingmode_opt = TRUE;
-        }
+    {
+        char *preload_env;
+        /* If LD_PRELOAD is alread set and this system does not support 
+           multiple libs in LD_PRELOAD, use use --mappingmode. */
+        preload_env = getenv("LD_PRELOAD");
+        if ( (preload_env != NULL) && (*preload_env != '\0') )
+            {
+                fprintf (stderr, 
+                         "%s: LD_PRELOAD is already set. Using --mappingmode\n", 
+                         programname);
+                mappingmode_opt = TRUE;
+            }
+    }
 #endif
     
     /* Check if preload library is available */
     {
-        void *handle = dlopen (PRELOAD_LIBRARY, RTLD_LAZY);
+        void *handle = NULL;
+        /* Set PID_ENV_NAME to -1. libxalflaunch.so knows about this case
+           and refrains from doing anything (like unsetting an 
+           original LD_PRELOAD) */
+        putenv (PID_ENV_NAME"=-1");
+        handle = dlopen (PRELOAD_LIBRARY, RTLD_LAZY);
         if (!handle)
             {
                 fprintf (stderr, 
@@ -329,12 +339,18 @@ static int
 launch_application (int mappingmode_opt, char **argv) 
 {
     int pid;
-    char *preload_string;
+    char *preload_string = NULL;
+    char *saved_preload = NULL;
+    char *saved_preload_env = NULL;
     
     /* Set up preload_string */
 #ifdef MULTI_PRELOAD
-    if (getenv("LD_PRELOAD") != NULL)
-        preload_string = g_strconcat ("LD_PRELOAD=", getenv("LD_PRELOAD"), ":", PRELOAD_LIBRARY, NULL);
+    saved_preload = getenv("LD_PRELOAD");
+    if (saved_preload != NULL)
+        {
+            preload_string = g_strconcat ("LD_PRELOAD=", saved_preload, ":", PRELOAD_LIBRARY, NULL);
+            saved_preload_env = g_strconcat (SAVED_PRELOAD_NAME"=", saved_preload, NULL);
+        }
     else
         preload_string = g_strconcat ("LD_PRELOAD=", PRELOAD_LIBRARY, NULL);
 #else 
@@ -354,7 +370,7 @@ launch_application (int mappingmode_opt, char **argv)
     {
 	char *pid_string;
 
-	pid_string = g_strconcat (PID_PROPERTY_NAME, "=", launch_pid, NULL);
+	pid_string = g_strconcat (PID_ENV_NAME, "=", launch_pid, NULL);
 	switch (pid = fork ())
 	    {
 	    case -1:
@@ -364,6 +380,8 @@ launch_application (int mappingmode_opt, char **argv)
 		if (!mappingmode_opt) 
 		    {
 			putenv (preload_string);
+                        if (saved_preload_env)
+                            putenv (saved_preload_env);
 			putenv (pid_string);
 		    }
 		execvp (argv[optind], argv+optind);
@@ -961,6 +979,7 @@ init_animation (struct anim_data_struct* anim_data)
     GtkStyle *style;
     GdkGC *gc;
     int i;
+    int pointer_x, pointer_y;
 
     xpm_array[0] = sp0_xpm;
     xpm_array[1] = sp1_xpm;
@@ -975,13 +994,21 @@ init_animation (struct anim_data_struct* anim_data)
     style = gtk_widget_get_default_style();
     gc = style->black_gc;
 
+    /* Fetch pointer position */
+    gdk_window_get_pointer (gdk_window_ref_from_xid (GDK_ROOT_WINDOW ()) , &pointer_x, &pointer_y, NULL);
+    /* The frames are 48x48 pixels. Center star at cursor. */
+    pointer_x -= 24;
+    if (pointer_x < 0) pointer_x = 0;
+    pointer_y -= 24;
+    if (pointer_y < 0) pointer_y = 0;
+    
     for (i = 0; i < MAX_FRAMES; i++)
         {
             /* Create windows */
             anim_data->windows[i] = gtk_window_new (GTK_WINDOW_POPUP);
             gtk_window_set_wmclass (GTK_WINDOW(anim_data->windows[i]), "anim", "xalf");     
             gtk_widget_realize (anim_data->windows[i]);
-            gtk_widget_set_uposition (anim_data->windows[i], 50, 20);
+            gtk_widget_set_uposition (anim_data->windows[i], pointer_x, pointer_y);
 
             /* Create fixed container */
             fixed = gtk_fixed_new();
